@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import NamedTuple, Optional
+from typing import Dict, NamedTuple, Optional
 
 from PyQt5.QtGui import QFont, QPainterPath
 
@@ -25,7 +25,7 @@ class _CachedTextPath(NamedTuple):
     generation_font_size: int
 
 
-_PATH_CACHE: dict[_CachedTextKey, _CachedTextPath] = {}
+_PATH_CACHE: Dict[_CachedTextKey, _CachedTextPath] = {}
 
 """NOTE: We can actually optimize this even further. We can modify
 q_clipping_path so it explicitly stores paint results in the global
